@@ -1,19 +1,42 @@
-#' Create a new cache
+#' Functions to create and work with a cache
 #'
 #' @param cachePath A path describing the directory in which to create
 #'   the database file(s)
-#' @param drv A driver, passed to \code{dbConnect}
-#' @param force Logical. Should it create a cache in the \code{cachePath},
+#' @inheritParams Cache
+#' @param drv A driver, passed to `dbConnect`
+#' @param force Logical. Should it create a cache in the `cachePath`,
 #'   even if it already exists, overwriting.
 #' @importFrom data.table data.table
 #' @importFrom DBI dbConnect dbDisconnect dbWriteTable
 #' @inheritParams DBI::dbConnect
 #' @inheritParams DBI::dbWriteTable
-#' @rdname cache-tools
+#' @rdname CacheHelpers
+#' @details
+#' `createCache` function will create a Cache folder structure and necessary files, based on
+#' the particular `drv` or `conn` provided.
+#'
+#' @return
+#' `createCache` does not return a value; it is called for side effects.
+#'
 #' @export
+#' @examples
+#' data.table::setDTthreads(2)
+#' newCache <- tempdir2("cacheHelperExamples")
+#' createCache(newCache)
+#'
+#' out <- Cache(rnorm(1), cachePath = newCache)
+#' cacheId <- gsub("cacheId:", "", attr(out, "tags"))
+#' loadFromCache(newCache, cacheId = cacheId)
+#'
+#' rmFromCache(newCache, cacheId = cacheId)
+#'
+#' # clean up
+#' unlink(dirname(newCache), recursive = TRUE)
+#'
 createCache <- function(cachePath = getOption("reproducible.cachePath"),
                         drv = getOption("reproducible.drv", RSQLite::SQLite()),
-                        conn = getOption("reproducible.conn", NULL), force = FALSE) {
+                        conn = getOption("reproducible.conn", NULL), force = FALSE,
+                        verbose = getOption("reproducible.verbose")) {
   # browser(expr = exists("aaaa"))
   alreadyExists <- CacheIsACache(cachePath, drv = drv, conn = conn, create = TRUE)
   if (alreadyExists && force == FALSE) {
@@ -43,17 +66,26 @@ createCache <- function(cachePath = getOption("reproducible.cachePath"),
     #)
 }
 
-#' @rdname cache-tools
+#' Save an object to Cache
+#'
+#' This is not expected to be used by a user as it requires that the `cacheId`
+#' be calculated in exactly the same as it calculated inside `Cache` (which requires
+#' `match.call` to match arguments with their names, among other things).
+#'
 #' @inheritParams Cache
-#' @param cacheId The hash string representing the result of \code{.robustDigest}
+#' @param cacheId The hash string representing the result of `.robustDigest`
 #' @param obj The R object to save to the cache
-#' @param linkToCacheId Optional. If a \code{cacheId} is provided here, then a \code{file.link}
-#'   will be made to the file with that \code{cacheId} name in the cache repo.
+#' @param linkToCacheId Optional. If a `cacheId` is provided here, then a `file.link`
+#'   will be made to the file with that `cacheId` name in the cache repo.
 #'   This is used when identical outputs exist in the cache. This will save disk space.
+#' @return
+#' This is used for its side effects, namely, it will add the object to the cache and
+#' cache database.
 saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
                         drv = getOption("reproducible.drv", RSQLite::SQLite()),
                         conn = getOption("reproducible.conn", NULL), obj, userTags, cacheId,
-                        linkToCacheId = NULL) {
+                        linkToCacheId = NULL,
+                        verbose = getOption("reproducible.verbose")) {
   # browser(expr = exists("._saveToCache_1"))
   if (is.null(conn)) {
     conn <- dbConnectAll(drv, cachePath = cachePath)
@@ -85,37 +117,19 @@ saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
       linkToCacheId <- NULL
     else {
       messageCache("  (A file with identical properties already exists in the Cache: ",basename(ftL),"; ",
-              "The newly added (",basename(fts),") is a file.link to that file)")
+              "The newly added (",basename(fts),") is a file.link to that file)",
+              verbose = verbose)
     }
     fs <- file.size(fts)
   }
 
   if (is.null(linkToCacheId)) {
     fs <- saveFileInCacheFolder(obj, fts)
-    # if (getOption("reproducible.cacheSaveFormat", "rds") == "qs") {
-    #   .requireNamespace("qs", stopOnFALSE = TRUE)
-    #   for (attempt in 1:2) {
-    #     fs <- qs::qsave(obj, file = fts, nthreads = getOption("reproducible.nThreads", 1),
-    #                     preset = getOption("reproducible.qsavePreset", "high"))
-    #     fs1 <- file.size(fts)
-    #     if (!identical(fs, fs1)) {
-    #       if (attempt == 1) {
-    #         warning("Attempted to save to Cache, but save seemed to fail; trying again")
-    #       } else {
-    #         stop("Saving to Cache did not work correctly; file appears corrupted. Please retry")
-    #       }
-    #     } else {
-    #       break
-    #     }
-    #   }
-    # } else {
-    #   saveRDS(obj, file = fts)
-    #   fs <- file.size(fts)
-    # }
   }
   if (isTRUE(getOption("reproducible.useMemoise"))) {
     if (is.null(.pkgEnv[[cachePath]]))
       .pkgEnv[[cachePath]] <- new.env(parent = emptyenv())
+    obj <- makeMemoisable(obj)
     assign(cacheId, obj, envir = .pkgEnv[[cachePath]])
   }
 
@@ -144,20 +158,33 @@ saveToCache <- function(cachePath = getOption("reproducible.cachePath"),
               "Usually, a solution involves using quote and eval around the formulas ",
               "and defining functions in a package or otherwise clean space, ",
               "i.e., not inside another function.\n",
-              "See http://adv-r.had.co.nz/memory.html#gc and 'capturing environments'.")
+              "See http://adv-r.had.co.nz/memory.html#gc and 'capturing environments'.",
+              verbose = verbose)
     }
   }
   dt <- data.table("cacheId" = cacheId, "tagKey" = tagKey,
                    "tagValue" = tagValue, "createdDate" = as.character(Sys.time()))
-  a <- retry(retries = 250, exponentialDecayBase = 1.01, quote(
-    dbAppendTable(conn, CacheDBTableName(cachePath, drv), dt)))
+  if (getOption("reproducible.useMultipleDBFiles", FALSE)) {
+    dtFile <- CacheDBFileSingle(cachePath = cachePath, cacheId = cacheId)
+    saveFileInCacheFolder(dt, dtFile, cachePath = cachePath, cacheId = cacheId)
+
+  } else {
+    a <- retry(retries = 250, exponentialDecayBase = 1.01, quote(
+      dbAppendTable(conn, CacheDBTableName(cachePath, drv), dt)))
+  }
 
   return(obj)
 }
 
 #' @export
-#' @rdname cache-tools
+#' @rdname CacheHelpers
 #' @inheritParams CacheStoredFile
+#' @details
+#' `loadFromCache` is a function to get a single object from the cache, given its `cacheId`.
+
+#' @return
+#' `loadFromCache` returns the object from the cache that has the particular `cacheId`.
+#'
 loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
                           cacheId,
                           format = getOption("reproducible.cacheSaveFormat", "rds"),
@@ -170,10 +197,12 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
     isMemoised <- exists(cacheId, envir = .pkgEnv[[cachePath]])
     if (isTRUE(isMemoised)) {
       obj <- get(cacheId, envir = .pkgEnv[[cachePath]])
+      obj <- unmakeMemoisable(obj)
     }
   }
   if (!isTRUE(isMemoised)) {
     f <- CacheStoredFile(cachePath, cacheId, format)
+    f <- unique(f) # It is OK if there is a vector of unique cacheIds e.g., loadFromCache(showCache(userTags = "hi")$cacheId)
 
     # First test if it is correct format
     if (!file.exists(f)) {
@@ -192,7 +221,7 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
     }
     obj <- loadFile(f, format = format)
   }
-  obj <- dealWithClassOnRecovery(obj, cacheRepo = cachePath,
+  obj <- dealWithClassOnRecovery(obj, cachePath = cachePath,
                                  cacheId = cacheId,
                                  drv = drv, conn = conn)
 
@@ -207,7 +236,13 @@ loadFromCache <- function(cachePath = getOption("reproducible.cachePath"),
 #'
 #' @importFrom DBI dbClearResult dbSendStatement dbBind dbAppendTable
 #' @export
-#' @rdname cache-tools
+#' @rdname CacheHelpers
+#' @details
+#' `rmFromCache` removes one or more items from the cache, and updates the cache
+#' database files.
+#'
+#' @return
+#' `rmFromCache` has no return value; it is called for its side effects.
 rmFromCache <- function(cachePath = getOption("reproducible.cachePath"),
                         cacheId, drv = getOption("reproducible.drv", RSQLite::SQLite()),
                         conn = getOption("reproducible.conn", NULL),
@@ -232,23 +267,24 @@ rmFromCache <- function(cachePath = getOption("reproducible.cachePath"),
 
   dbClearResult(res)
 
-  unlink(CacheStoredFile(cachePath, hash = cacheId, format = format))
+  unlink(CacheStoredFile(cachePath, cacheId = cacheId, format = format))
 }
 
 dbConnectAll <- function(drv = getOption("reproducible.drv", RSQLite::SQLite()),
                          cachePath = getOption("reproducible.cachePath"),
-                         conn = getOption("reproducible.conn", NULL), create = TRUE) {
+                         conn = getOption("reproducible.conn", NULL), create = TRUE,
+                         verbose = getOption("reproducible.verbose")) {
   args <- list(drv = drv)
-  # browser(expr = exists("yyyy"))
   if (is(drv, "SQLiteDriver")) {
-    # if (!CacheIsACache(cachePath = cachePath, drv = drv, conn = conn))
-    #   if (isFALSE(create)) {
-    #     return(invisible())
-    #   }
     args <- append(args, list(dbname = CacheDBFile(cachePath, drv = drv, conn = conn),
                               synchronous = NULL))
-  } # other types of drv, e.g., Postgres can be done via env vars
-  do.call(dbConnect, args)
+  }
+  conn <- try(do.call(dbConnect, args), silent = TRUE)
+  if (is(conn, "try-error")) {
+    messageCache("There is no Cache at this location", verbose = verbose, verboseLevel = 1)
+    return(invisible(NULL))
+  }
+  conn
 }
 
 .emptyCacheTable <- data.table::data.table(cacheId = character(), tagKey = character(),
@@ -374,8 +410,32 @@ dbConnectAll <- function(drv = getOption("reproducible.drv", RSQLite::SQLite()),
 #' @inheritParams createCache
 #' @rdname CacheHelpers
 #' @export
+#' @return
+#' `CacheDBFile` returns the name of the database file for a given Cache.
 #' @details
-#' \code{CacheStoredFile} returns the file path to the file with the specified hash value.
+#' `CacheStoredFile` returns the file path to the file with the specified hash value.
+#'
+#' @examples
+#' data.table::setDTthreads(2)
+#' newCache <- tempdir2("cacheHelperExamples")
+#'
+#' # Given the drv and conn, creates the minimum infrastructure for a cache
+#' createCache(newCache)
+#'
+#' CacheDBFile(newCache) # identifies the database file
+#' CacheStorageDir(newCache) # identifies the directory where cached objects are stored
+#'
+#' out <- Cache(rnorm(1), cachePath = newCache)
+#' cacheId <- gsub("cacheId:", "", attr(out, "tags"))
+#' CacheStoredFile(newCache, cacheId = cacheId)
+#'
+#' # The name of the table inside the SQL database
+#' CacheDBTableName(newCache)
+#'
+#' CacheIsACache(newCache) # returns TRUE
+#'
+#' # clean up
+#' unlink(dirname(newCache), recursive = TRUE)
 CacheDBFile <- function(cachePath = getOption("reproducible.cachePath"),
                         drv = getOption("reproducible.drv", RSQLite::SQLite()),
                         conn = getOption("reproducible.conn", NULL)) {
@@ -401,6 +461,9 @@ CacheDBFile <- function(cachePath = getOption("reproducible.cachePath"),
 
 #' @rdname CacheHelpers
 #' @export
+#' @return
+#' `CacheStorageDir` returns the name of the directory where cached objects are
+#' stored.
 CacheStorageDir <- function(cachePath = getOption("reproducible.cachePath")) {
   if (useDBI()) {
     file.path(cachePath, "cacheOutputs")
@@ -410,34 +473,40 @@ CacheStorageDir <- function(cachePath = getOption("reproducible.cachePath")) {
 }
 
 #' @details
-#' \code{CacheStoredFile} returns the file path to the file with the specified hash value.
+#' `CacheStoredFile` returns the file path to the file with the specified hash value.
 #'
 #' @rdname CacheHelpers
 #' @export
-#' @param hash The cacheId or otherwise digested hash value, as character string.
+#' @param cacheId The cacheId or otherwise digested hash value, as character string.
 #' @param format The text string representing the file extension used normally by
-#'   different save formats; currently only \code{"rds"} or \code{"qs"}. Defaults
-#'   to \code{getOption("reproducible.cacheSaveFormat", "rds")}
-CacheStoredFile <- function(cachePath = getOption("reproducible.cachePath"), hash,
+#'   different save formats; currently only `"rds"` or `"qs"`. Defaults
+#'   to `getOption("reproducible.cacheSaveFormat", "rds")`
+#' @return
+#' `CacheStoredFile` returns the name of the file in which the cacheId object is stored.
+#' This can be loaded to memory with e.g., `loadFile`.
+CacheStoredFile <- function(cachePath = getOption("reproducible.cachePath"), cacheId,
                             format = getOption("reproducible.cacheSaveFormat", "rds")) {
   csf <- if (isTRUE(useDBI()) == FALSE) {
     "rda"
   } else {
     format
   }
-  csExtension <- if (csf == "qs") {
+  csExtension <- if (isTRUE("qs" %in% csf)) {
     "qs"
-  } else if (csf == "rds") {
+  } else if (isTRUE("rds" %in% csf)) {
     "rds"
   } else {
     "rda"
   }
-  filename <- paste(hash, csExtension, sep = ".")
+  filename <- paste(cacheId, csExtension, sep = ".")
   file.path(CacheStorageDir(cachePath), filename)
 }
 
 #' @rdname CacheHelpers
 #' @export
+#' @return
+#' `CacheDBTableName` returns the name of the table inside the SQL database, if that
+#' is being used.
 CacheDBTableName <- function(cachePath = getOption("reproducible.cachePath"),
                              drv = getOption("reproducible.drv", RSQLite::SQLite())) {
   if (!is(cachePath, "Path")) {
@@ -462,17 +531,19 @@ CacheDBTableName <- function(cachePath = getOption("reproducible.cachePath"),
 
 #' @rdname CacheHelpers
 #' @param create Logical. Currently only affects non RQSLite default drivers. If this
-#'   is \code{TRUE} and there is no Cache database, the function will create one.
+#'   is `TRUE` and there is no Cache database, the function will create one.
 #' @importFrom DBI dbListTables
 #' @export
+#' @return
+#' `CacheIsACache` returns a logical indicating whether the `cachePath` is currently
+#' a `reproducible` cache database.
 #' @details
-#' \code{CacheIsACache} returns a logical of whether the specified cachePath
+#' `CacheIsACache` returns a logical of whether the specified cachePath
 #'   is actually a functioning cache.
 CacheIsACache <- function(cachePath = getOption("reproducible.cachePath"), create = FALSE,
                           drv = getOption("reproducible.drv", RSQLite::SQLite()),
                           conn = getOption("reproducible.conn", NULL)) {
   checkPath(cachePath, create = TRUE)
-  # browser(expr = exists("._CacheIsACache_1"))
   if (useDBI()) {
     if (is.null(conn)) {
       conn <- dbConnectAll(drv, cachePath = cachePath)
@@ -493,7 +564,7 @@ CacheIsACache <- function(cachePath = getOption("reproducible.cachePath"), creat
       tableShouldBe <- CacheDBTableName(cachePath)
       if (length(tablesInDB) == 1) {
         if (!any(tablesInDB %in% tableShouldBe) && grepl(type, "SQLite")) {
-          warning(paste0("The table in the Cache repo does not match the cacheRepo. ",
+          warning(paste0("The table in the Cache repo does not match the cachePath. ",
                      "If this is because of a moved repository (i.e., files ",
                      "copied), then it is being updated automatically. ",
                      "If not, cache is in an error state. ",
@@ -520,32 +591,47 @@ CacheIsACache <- function(cachePath = getOption("reproducible.cachePath"), creat
 #' Deal with moved cache issues
 #'
 #' If a user manually copies a complete Cache folder (including the db file and rasters folder),
-#' there are issues that must be addressed. Primarily, the db table must be renamed. Run
+#' there are issues that must be addressed, depending on the Cache backend used.
+#' If using DBI (e.g., RSQLite or Postgres), the db table must be renamed. Run
 #' this function after a manual copy of a cache folder. See examples for one way to do that.
 #'
-#' @param  new Either the path of the new \code{cachePath} where the cache was moved or copied to, or
+#' @param  new Either the path of the new `cachePath` where the cache was moved or copied to, or
 #'   the new DB Table Name
-#' @param  old Optional, if there is only one table in the \code{new} cache path.
-#'   Either the path of the previous \code{cachePath} where the cache was moved or copied from, or
+#' @param  old Optional, if there is only one table in the `new` cache path.
+#'   Either the path of the previous `cachePath` where the cache was moved or copied from, or
 #'   the old DB Table Name
 #' @inheritParams Cache
 #' @importFrom DBI dbListTables
 #' @export
+#' @details
+#' When the backend database for a `reproducinle` cache is an SQL database, the files
+#' on disk cannot be copied manually to a new location because they contain internal
+#' tables. Because `reproducible` gives the main table a name based on the `cachePath`
+#' path, calls to `Cache` will attempt to call this internally if it detects a
+#' name mismatch.
+#' @return
+#' `movedCache` does not return anything; it is called for its side effects.
+#'
 #' @examples
-#' tmpCache <- file.path(tempdir(), "tmpCache")
-#' tmpdir <- file.path(tempdir(), "tmpdir")
-#' bb <- Cache(rnorm, 1, cacheRepo = tmpCache)
+#' data.table::setDTthreads(2)
+#' tmpdir <- "tmpdir"
+#' tmpCache <- "tmpCache"
+#' tmpCacheDir <- normalizePath(file.path(tempdir(), tmpCache), mustWork = FALSE)
+#' tmpdirPath <- normalizePath(file.path(tempdir(), tmpdir), mustWork = FALSE)
+#' bb <- Cache(rnorm, 1, cachePath = tmpCacheDir)
 #'
 #' # Copy all files from tmpCache to tmpdir
-#' froms <- normPath(dir(tmpCache, recursive = TRUE, full.names = TRUE))
-#' checkPath(file.path(tmpdir, "rasters"), create = TRUE)
-#' checkPath(file.path(tmpdir, "cacheOutputs"), create = TRUE)
+#' froms <- normalizePath(dir(tmpCacheDir, recursive = TRUE, full.names = TRUE),
+#'                        mustWork = FALSE)
+#' dir.create(file.path(tmpdirPath, "rasters"), recursive = TRUE)
+#' dir.create(file.path(tmpdirPath, "cacheOutputs"), recursive = TRUE)
 #' file.copy(from = froms, overwrite = TRUE,
-#'           to = gsub(normPath(tmpCache), normPath(tmpdir), froms))
+#'           to = gsub(tmpCache, tmpdir, froms))
 #'
-#' # Must use 'movedCache' to update the database table
-#' movedCache(new = tmpdir, old = tmpCache)
-#' bb <- Cache(rnorm, 1, cacheRepo = tmpdir) # should recover the previous call
+#' # Can use 'movedCache' to update the database table, though will generally
+#' #   happen automatically, with message indicating so
+#' movedCache(new = tmpdirPath, old = tmpCacheDir)
+#' bb <- Cache(rnorm, 1, cachePath = tmpdirPath) # should recover the previous call
 #'
 movedCache <- function(new, old, drv = getOption("reproducible.drv", RSQLite::SQLite()),
                        conn = getOption("reproducible.conn", NULL)) {
@@ -624,3 +710,8 @@ saveFileInCacheFolder <- function(obj, fts, cachePath, cacheId) {
   }
   fs
 }
+
+CacheDBFileSingle <- function(cachePath, cacheId) {
+  paste0(CacheStoredFile(cachePath = cachePath, cacheId = cacheId),
+         paste0(".dt.", getOption("reproducible.cacheSaveFormat")))
+}
