@@ -1,319 +1,27 @@
-################################################################################
-#' Add extra tags to an archive based on class
-#'
-#' This is a generic definition that can be extended according to class.
-#'
-#' @return A character vector of new tags.
-#'
-#' @param object Any R object.
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname tagsByClass
-#' @examples
-#' .tagsByClass(character()) # Nothing interesting. Other packages will make methods
-#'
-setGeneric(".tagsByClass", function(object) {
-  standardGeneric(".tagsByClass")
-})
-
-#' @export
-#' @rdname tagsByClass
-setMethod(
-  ".tagsByClass",
-  signature = "ANY",
-  definition = function(object) {
-    NULL
-  })
-
-################################################################################
-#' Create a custom cache message by class
-#'
-#' This is a generic definition that can be extended according to class.
-#'
-#' @return Nothing; called for its messaging side effect.
-#'
-#' @param object Any R object.
-#' @param functionName A character string indicating the function name
-#' @param fromMemoise Logical. If \code{TRUE}, the message will be about
-#'        recovery from memoised copy
-#' @inheritParams Cache
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname cacheMessage
-#' @examples
-#' a <- 1
-#' .cacheMessage(a, "mean")
-#'
-setGeneric(".cacheMessage", function(object, functionName,
-                                     fromMemoise = getOption("reproducible.useMemoise", TRUE),
-                                     verbose = getOption("reproducible.verbose", 1)) {
-  standardGeneric(".cacheMessage")
-})
-
-#' @export
-#' @rdname cacheMessage
-setMethod(
-  ".cacheMessage",
-  signature = "ANY",
-  definition = function(object, functionName, fromMemoise, verbose = getOption("reproducible.verbose", 1)) {
-    if (isTRUE(fromMemoise)) {
-      messageCache(.loadedCacheMsg(.loadedMemoisedResultMsg, functionName), verbose = verbose)
-    } else if (!is.na(fromMemoise)) {
-      messageCache(.loadedCacheMsg(.loadedCacheResultMsg, functionName), " ",
-                   .addingToMemoisedMsg, sep = "", verbose = verbose)
-    } else {
-      messageCache(.loadedCacheMsg(.loadedCacheResultMsg, functionName), verbose = verbose)
-    }
-  })
-
-################################################################################
-#' Add tags to object
-#'
-#' This is a generic definition that can be extended according to class.
-#' This function and methods should do "deep" copy for archiving purposes.
-#'
-#' @inheritParams Cache
-#'
-#' @param object Any R object.
-#'
-#' @param FUN A function
-#'
-#' @param preDigestByClass A list, usually from \code{.preDigestByClass}
-#'
-#' @return New object with tags attached.
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname addTagsToOutput
-#'
-setGeneric(".addTagsToOutput", function(object, outputObjects, FUN, preDigestByClass) { # nolint
-  standardGeneric(".addTagsToOutput")
-})
-
-#' @export
-#' @rdname addTagsToOutput
-setMethod(
-  ".addTagsToOutput",
-  signature = "ANY",
-  definition = function(object, outputObjects, FUN, preDigestByClass) { # nolint
-    object
-  })
-
-################################################################################
-#' Any miscellaneous things to do before \code{.robustDigest} and after \code{FUN} call
-#'
-#' The default method for \code{preDigestByClass} and simply returns \code{NULL}.
-#' There may be methods in other packages.
-#'
-#' @param object Any R object.
-#'
-#' @return A list with elements that will likely be used in \code{.postProcessing}
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname preDigestByClass
-#' @examples
-#' a <- 1
-#' .preDigestByClass(a) # returns NULL in the simple case here.
-#'
-setGeneric(".preDigestByClass", function(object) { # nolint
-  standardGeneric(".preDigestByClass")
-})
-
-#' @export
-#' @rdname preDigestByClass
-setMethod(
-  ".preDigestByClass",
-  signature = "ANY",
-  definition = function(object) { # nolint
-    NULL
-  })
-
-################################################################################
-#' Check for cache repository info in ...
-#'
-#' This is a generic definition that can be extended according to class.
-#' Normally, \code{checkPath} can be called directly, but does not have class-specific methods.
-#'
-#' @param object An R object
-#' @param create Logical. If TRUE, then it will create the path for cache.
-#' @inheritParams Cache
-#'
-#' @return A character string with a path to a cache repository.
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname checkCacheRepo
-#' @examples
-#' a <- "test"
-#' .checkCacheRepo(a) # no cache repository supplied
-#'
-setGeneric(".checkCacheRepo", function(object, create = FALSE,
-                                       verbose = getOption("reproducible.verbose", 1)) {
-  standardGeneric(".checkCacheRepo")
-})
-
-#' @export
-#' @rdname checkCacheRepo
-setMethod(
-  ".checkCacheRepo",
-  signature = "ANY",
-  definition = function(object, create, verbose = getOption("reproducible.verbose", 1)) {
-    cacheRepo <- tryCatch(checkPath(object, create), error = function(x) {
-      cacheRepo <- if (isTRUE(nzchar(getOption("reproducible.cachePath")[1]))) {
-        tmpDir <- .reproducibleTempCacheDir()
-        # Test whether the user has accepted the default. If yes, then give message.
-        #  If no, then user is aware and doesn't need a message
-        if (any(identical(normPath(tmpDir), normPath(getOption("reproducible.cachePath"))))) {
-          messageCache("No cacheRepo supplied and getOption('reproducible.cachePath') is inside a temporary directory;\n",
-                       "  this will not persist across R sessions.", verbose = verbose)
-        }
-        getOption("reproducible.cachePath", tmpDir)
-      } else {
-        messageCache("No cacheRepo supplied. Using ",.reproducibleTempCacheDir(), verbose = verbose)
-        .reproducibleTempCacheDir()
-      }
-      checkPath(path = cacheRepo, create = create)
-    })
-  })
-
-################################################################################
-#' Make any modifications to object recovered from cacheRepo
-#'
-#' This is a generic definition that can be extended according to class.
-#'
-#' @inheritParams Cache
-#'
-#' @param object Any R object
-#'
-#' @return The object, modified
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname prepareOutput
-#' @examples
-#' a <- 1
-#' .prepareOutput(a) # does nothing
-#'
-#' b <- "NULL"
-#' .prepareOutput(b) # converts to NULL
-#'
-#' library(raster)
-#' r <- raster(extent(0,10,0,10), vals = 1:100)
-#'
-#' # write to disk manually -- will be in tempdir()
-#' r <- writeRaster(r, file = tempfile())
-#'
-#' # copy it to the cache repository
-#' r <- .prepareOutput(r, tempdir())
-setGeneric(".prepareOutput", function(object, cacheRepo, ...) {
-  standardGeneric(".prepareOutput")
-})
-
-# @export
-# @rdname prepareOutput
-# @importFrom Require normPath
-# @importFrom RSQLite SQLite
-# setMethod(
-#   ".prepareOutput",
-#   signature = "Raster",
-#   definition = function(object, cacheRepo, drv = getOption("reproducible.drv", RSQLite::SQLite()),
-#                         conn = getOption("reproducible.conn", NULL), ...) {
-#     # with this call to .prepareFileBackedRaster, it is from the same function call as a previous time
-#     #  overwrite is ok
-#     # .prepareFileBackedRaster(object, repoDir = cacheRepo, drv = drv, conn = conn, ...)
-#     # browser(expr = exists("._prepareOutputs_1"))
-#     if (isTRUE(fromDisk(object))) {
-#       fns <- Filenames(object, allowMultiple = FALSE)
-#       fpShould <- normPath(file.path(cacheRepo, "rasters"))
-#       isCorrect <- unlist(lapply(normPath(file.path(fpShould, basename(fns))),
-#                                  function(x) any(grepl(x, fns))))
-#       if (!any(isCorrect)) {
-#         if (is(object, "RasterStack")) {
-#           # browser(expr = exists("._prepareOutputs_2"))
-#           for (i in seq(nlayers(object))) {
-#             object@layers[[i]]@file@name <- gsub(dirname(object@layers[[i]]@file@name),
-#                                                  fpShould, object@layers[[i]]@file@name)
-#           }
-#         } else {
-#           object@file@name <- gsub(unique(dirname(fns)), fpShould, fns)
-#         }
-#       }
-#     }
-#     object
-#   })
-
-#' @export
-#' @rdname prepareOutput
-setMethod(
-  ".prepareOutput",
-  signature = "ANY",
-  definition = function(object, cacheRepo, ...) {
-    if (is.character(object)) {
-      if (length(object) == 1) {
-        # need something to attach tags to if it is actually NULL
-        if (identical(object, "NULL")) object <- NULL
-      }
-    }
-    object
-  })
-
-################################################################################
-#' Add an attribute to an object indicating which named elements change
-#'
-#' This is a generic definition that can be extended according to class.
-#'
-#' @param object Any R object returned from a function
-#' @param preDigest The full, element by element hash of the input arguments to that same function,
-#' e.g., from \code{.robustDigest}
-#' @param origArguments These are the actual arguments (i.e., the values, not the names) that
-#'        were the source for \code{preDigest}
-#' @param ... Anything passed to methods.
-#'
-#' @return The object, modified
-#'
-#' @author Eliot McIntire
-#' @export
-#' @rdname addChangedAttr
-#' @examples
-#' a <- 1
-#' .addChangedAttr(a) # does nothing because default method is just a pass through
-setGeneric(".addChangedAttr", function(object, preDigest, origArguments, ...) {
-  standardGeneric(".addChangedAttr")
-})
-
-#' @export
-#' @rdname addChangedAttr
-setMethod(
-  ".addChangedAttr",
-  signature = "ANY",
-  definition = function(object, preDigest, origArguments, ...) {
-    object
-  })
 
 #' A set of helpers for Cache
 #'
 #' These are internal only.
 #'
 #' @param FUN A function
-#' @param ... passing the \code{...} from outer function, which will include potential
-#'        arguments to the \code{FUN}
+#' @param ... passing the `...` from outer function, which will include potential
+#'        arguments to the `FUN`
 #' @param overrideCall A character string indicating a different (not "Cache") function
 #'        name to search for. Mostly so that this works with deprecated "cache".
-#' @param isPipe Logical. If the call to \code{getFunctionName} is coming from a pipe, there is more
-#'               information available. Specifically, \code{._lhs} which is already a call.
 #' @note If the function cannot figure out a clean function name, it returns "internal"
 #'
 #' @author Eliot McIntire
 #' @importFrom methods selectMethod showMethods
 #' @importFrom utils head
 #' @keywords internal
-#' @rdname cache-helpers
-getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # nolint
+getFunctionName <- function(FUN, ..., overrideCall) { # nolint
   callIndex <- numeric()
-  scalls <- sys.calls()
+  scalls <- sys.calls() # needed for nesting level
+  functionName <- NULL # initiate this here, so we can know if it is found
+  if (is(FUN, "list")) {
+    functionName <- names(FUN)
+    FUN <- FUN[[1]]
+  }
   if (isS4(FUN)) {
     # Have to extract the correct dispatched method
     firstElems <- strsplit(showMethods(FUN, inherited = TRUE, printTo = FALSE), split = ", ")
@@ -337,15 +45,9 @@ getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # no
     })
     signat <- unlist(sigArgs[unlist(lapply(sigArgs, function(y) any(y)))])
 
-    if (isPipe) {
-      matchedCall <- as.list(
-        match.call(FUN, list(...)$._lhs) # already a call
-      )
-    } else {
-      matchedCall <- as.list(
-        match.call(FUN, call(name = FUN@generic, list(...)))
-      )
-    }
+    matchedCall <- as.list(
+      match.call(FUN, call(name = FUN@generic, list(...)))
+    )
 
     matchedCall <- matchedCall[nzchar(names(matchedCall))]
     ff <- match(names(matchedCall), FUN@signature[signat])
@@ -364,70 +66,72 @@ getFunctionName <- function(FUN, originalDots, ..., overrideCall, isPipe) { # no
     functionName <- FUN@generic
     FUN <- methodUsed@.Data  # nolint
   } else {
-    if (!missing(overrideCall)) {
-      callIndices <- .grepSysCalls(scalls, pattern = paste0("^", overrideCall))
-      functionCall <- scalls[callIndices]
-    } else {
-      callIndices <- .grepSysCalls(scalls,
-                                   pattern = "^Cache|^SpaDES::Cache|^reproducible::Cache|^cloudCache")
-      callIndicesDoCall <- .grepSysCalls(scalls, pattern = "^do.call")
-      doCall1st2Elements <- lapply(scalls[callIndicesDoCall], function(x) x[1:2])
-      callIndicesDoCall <- callIndicesDoCall[grep("Cache", doCall1st2Elements)]
-      # The next line takes too long to grep if scalls has enormous objects
-      # callIndices <- grep(scalls, pattern = "^Cache|^SpaDES::Cache|^reproducible::Cache")
-      callIndices <- unique(sort(c(callIndices, callIndicesDoCall)))
-      functionCall <- scalls[callIndices]
-    }
-    if (length(functionCall)) {
-      # for() loop is a work around for R-devel that produces a different final call in the
-      # sys.calls() stack which is NOT .Method ... and produces a Cache(FUN = FUN...)
-      for (callIndex in head(rev(callIndices), 2)) {
-        if (!missing(overrideCall)) {
-          env <- sys.frames()[[callIndex]]
-          matchedCall <- match.call(get(overrideCall, envir = env), scalls[[callIndex]])#parse(text = callIndex))
-          forms <- tryCatch("FUN" %in% formalArgs(overrideCall), error = function(x) NULL)
-          if (!is.null(forms)) {
-            functionName <- matchedCall$FUN
+    if (is.null(functionName)) {
+      if (!missing(overrideCall)) {
+        callIndices <- .grepSysCalls(scalls, pattern = paste0("^", overrideCall))
+        functionCall <- scalls[callIndices]
+      } else {
+        callIndices <- .grepSysCalls(scalls,
+                                     pattern = "^Cache|^SpaDES::Cache|^reproducible::Cache|^cloudCache")
+        callIndicesDoCall <- .grepSysCalls(scalls, pattern = "^do.call")
+        doCall1st2Elements <- lapply(scalls[callIndicesDoCall], function(x) x[1:2])
+        callIndicesDoCall <- callIndicesDoCall[grep("Cache", doCall1st2Elements)]
+        # The next line takes too long to grep if scalls has enormous objects
+        # callIndices <- grep(scalls, pattern = "^Cache|^SpaDES::Cache|^reproducible::Cache")
+        callIndices <- unique(sort(c(callIndices, callIndicesDoCall)))
+        functionCall <- scalls[callIndices]
+      }
+      if (length(functionCall)) {
+        # for() loop is a work around for R-devel that produces a different final call in the
+        # sys.calls() stack which is NOT .Method ... and produces a Cache(FUN = FUN...)
+        for (callIndex in head(rev(callIndices), 2)) {
+          if (!missing(overrideCall)) {
+            env <- sys.frames()[[callIndex]]
+            matchedCall <- match.call(get(overrideCall, envir = env), scalls[[callIndex]])#parse(text = callIndex))
+            forms <- tryCatch("FUN" %in% formalArgs(overrideCall), error = function(x) NULL)
+            if (!is.null(forms)) {
+              functionName <- matchedCall$FUN
+            } else {
+              functionName <- matchedCall[[2]]
+            }
           } else {
-            functionName <- matchedCall[[2]]
-          }
-        } else {
-          foundCall <- FALSE
-          if (exists("callIndicesDoCall", inherits = FALSE))
-            if (length(callIndicesDoCall) > 0) {
-              if (callIndex %in% callIndicesDoCall) {
-                mcDoCall <- match.call(do.call, scalls[[callIndex]])
-                for (i in 1:2) {
-                  fnLookup <- try(eval(mcDoCall$args, envir = sys.frames()[[callIndex - i]]), silent = TRUE)
-                  if (!is(fnLookup, "try-error"))
-                    break
+            foundCall <- FALSE
+            if (exists("callIndicesDoCall", inherits = FALSE))
+              if (length(callIndicesDoCall) > 0) {
+                if (callIndex %in% callIndicesDoCall) {
+                  mcDoCall <- match.call(do.call, scalls[[callIndex]])
+                  for (i in 1:2) {
+                    fnLookup <- try(eval(mcDoCall$args, envir = sys.frames()[[callIndex - i]]), silent = TRUE)
+                    if (!is(fnLookup, "try-error"))
+                      break
+                  }
+                  functionName <- if (isTRUE("FUN" %in% names(fnLookup)))
+                    fnLookup$FUN
+                  else
+                    fnLookup[[1]]
+
+                  foundCall <- TRUE
                 }
-                functionName <- if (isTRUE("FUN" %in% names(fnLookup)))
-                  fnLookup$FUN
-                else
-                  fnLookup[[1]]
-
-                foundCall <- TRUE
               }
+            if (!foundCall) {
+              matchedCall <- try(match.call(Cache, scalls[[callIndex]]), silent = TRUE)#parse(text = callIndex))
+              functionName <- if (!is(matchedCall, "try-error"))
+                matchedCall$FUN
+              else
+                ""
             }
-          if (!foundCall) {
-            matchedCall <- try(match.call(Cache, scalls[[callIndex]]), silent = TRUE)#parse(text = callIndex))
-            functionName <- if (!is(matchedCall, "try-error"))
-              matchedCall$FUN
-            else
-              ""
           }
+          functionName <- if (is(functionName, "name")) {
+            deparse(functionName, width.cutoff = 300)
+          } else {
+            "FUN"
+          }
+
+          if (all(functionName != c("FUN")) && all(functionName != c("NULL"))) break
         }
-        functionName <- if (is(functionName, "name")) {
-          deparse(functionName, width.cutoff = 300)
-        } else {
-          "FUN"
-        }
-
-        if (all(functionName != c("FUN")) && all(functionName != c("NULL"))) break
+      } else {
+        functionName <- ""
       }
-    } else {
-      functionName <- ""
     }
     .FUN <- FUN  # nolint
   }
@@ -459,8 +163,8 @@ setClass("Path", slots = c(.Data = "character"), contains = "character", prototy
 #'
 #' It is often difficult or impossible to know algorithmically whether a
 #' character string corresponds to a valid filepath.
-#' In the case where it is en existing file, \code{file.exists} can work.
-#' But if it does not yet exist, e.g., for a \code{save}, it is difficult to know
+#' In the case where it is en existing file, `file.exists` can work.
+#' But if it does not yet exist, e.g., for a `save`, it is difficult to know
 #' whether it is a valid path before attempting to save to the path.
 #'
 #' This function can be used to remove any ambiguity about whether a character
@@ -470,19 +174,25 @@ setClass("Path", slots = c(.Data = "character"), contains = "character", prototy
 #' to detect a candidate for recovery from the cache.
 #' Paths, are different. While they are character strings, there are many ways to
 #' write the same path. Examples of identical meaning, but different character strings are:
-#' path expanding of \code{~} vs. not, double back slash vs. single forward slash,
+#' path expanding of `~` vs. not, double back slash vs. single forward slash,
 #' relative path vs. absolute path.
 #' All of these should be assessed for their actual file or directory location,
 #' NOT their character string. By converting all character string that are actual
-#' file or directory paths with this function, then \code{Cache} will correctly assess
+#' file or directory paths with this function, then `Cache` will correctly assess
 #' the location, NOT the character string representation.
 #'
-#' @param obj A character string to convert to a \code{Path}.
+#' @param obj A character string to convert to a `Path`.
 #' @param nParentDirs A numeric indicating the number of parent directories starting
 #'                    from basename(obj) = 0 to keep for the digest
 #'
 #' @export
 #' @rdname Path-class
+#' @return
+#' A vector of class `Path`, which is similar to a character, but
+#' has an attribute indicating how deep the Path should be
+#' considered "digestible". In other words, most of the time, only some
+#' component of an absolute path is relevant for evaluating its purpose in
+#' a Cache situation. In general, this is usually equivalent to just the "relative" path
 #'
 #' @examples
 #' tmpf <- tempfile(fileext = ".csv")
@@ -510,8 +220,8 @@ asPath.null <- function(obj, nParentDirs = 0) {  # nolint
   return(NULL)
 }
 
-#' If using \code{as("string", "Path")}, there is no option to pass \code{nParentDirs}.
-#' So, using \code{asPath} directly (e.g., \code{asPath("string", 0))}) is preferred.
+#' If using `as("string", "Path")`, there is no option to pass `nParentDirs`.
+#' So, using `asPath` directly (e.g., `asPath("string", 0))`) is preferred.
 #' @export
 #' @importFrom methods new
 #' @rdname Path-class
@@ -738,12 +448,12 @@ setAs(from = "character", to = "Path", function(from) {
   return(obj)
 }
 
-#' Copy a file using \code{robocopy} on Windows and \code{rsync} on Linux/macOS
+#' Copy a file using `robocopy` on Windows and `rsync` on Linux/macOS
 #'
-#' This is replacement for \code{file.copy}, but for one file at a time.
-#' The additional feature is that it will use \code{robocopy} (on Windows) or
-#' \code{rsync} on Linux or Mac, if they exist.
-#' It will default back to \code{file.copy} if none of these exists.
+#' This is replacement for `file.copy`, but for one file at a time.
+#' The additional feature is that it will use `robocopy` (on Windows) or
+#' `rsync` on Linux or Mac, if they exist.
+#' It will default back to `file.copy` if none of these exists.
 #' If there is a possibility that the file already exists, then this function
 #' should be very fast as it will do "update only", i.e., nothing.
 #'
@@ -751,29 +461,31 @@ setAs(from = "character", to = "Path", function(from) {
 #'
 #' @param to The new file.
 #'
-#' @param useRobocopy For Windows, this will use a system call to \code{robocopy}
-#'        which appears to be much faster than the internal \code{file.copy} function.
-#'        Uses \code{/MIR} flag. Default \code{TRUE}.
+#' @param useRobocopy For Windows, this will use a system call to `robocopy`
+#'        which appears to be much faster than the internal `file.copy` function.
+#'        Uses `/MIR` flag. Default `TRUE`.
 #'
-#' @param overwrite Passed to \code{file.copy}
+#' @param overwrite Passed to `file.copy`
 #'
 #' @param delDestination Logical, whether the destination should have any files deleted,
-#' if they don't exist in the source. This is \code{/purge} for robocopy and --delete for
+#' if they don't exist in the source. This is `/purge` for robocopy and --delete for
 #' rsync.
 #'
-#' @param create Passed to \code{checkPath}.
+#' @param create Passed to `checkPath`.
 #'
 #' @param silent Should a progress be printed.
 #'
 #' @author Eliot McIntire and Alex Chubaty
 #' @rdname copyFile
+#' @return
+#' This function is called for its side effect, i.e., a file is copied `from` to `to`.
 #'
 #' @examples
 #' tmpDirFrom <- file.path(tempdir(), "example_fileCopy_from")
 #' tmpDirTo <- file.path(tempdir(), "example_fileCopy_to")
 #' tmpFile1 <- tempfile("file1", tmpDirFrom, ".csv")
 #' tmpFile2 <- tempfile("file2", tmpDirFrom, ".csv")
-#' checkPath(tmpDirFrom, create = TRUE)
+#' dir.create(tmpDirFrom, recursive = TRUE, showWarnings = FALSE)
 #' f1 <- normalizePath(tmpFile1, mustWork = FALSE)
 #' f2 <- normalizePath(tmpFile2, mustWork = FALSE)
 #' t1 <- normalizePath(file.path(tmpDirTo, basename(tmpFile1)), mustWork = FALSE)
@@ -796,7 +508,6 @@ copySingleFile <- function(from = NULL, to = NULL, useRobocopy = TRUE,
                            #copyRasterFile = TRUE, clearRepo = TRUE,
                            create = TRUE, silent = FALSE) {
   if (any(length(from) != 1, length(to) != 1)) stop("from and to must each be length 1")
-  origDir <- getwd()
   useFileCopy <- identical(dirname(from), dirname(to))
 
   lapply(unique(dirname(to)), checkPath, create = create)
@@ -858,7 +569,6 @@ copySingleFile <- function(from = NULL, to = NULL, useRobocopy = TRUE,
     file.copy(from = from, to = to, overwrite = overwrite, recursive = FALSE)
   }
 
-  setwd(origDir)
   return(invisible(to))
 }
 
@@ -869,7 +579,6 @@ copyFile <- Vectorize(copySingleFile, vectorize.args = c("from", "to"))
 #' @importFrom methods slotNames
 #' @importFrom digest digest
 #' @importFrom raster res crs extent
-#' @rdname cache-helpers
 .digestRasterLayer <- function(object, length, algo, quick) {
   # metadata -- only a few items of the long list because one thing (I don't recall)
   #  doesn't cache consistently
@@ -1024,21 +733,22 @@ copyFile <- Vectorize(copySingleFile, vectorize.args = c("from", "to"))
 
 
 ################################################################################
-#' Sort or order any named object with dotted names and underscores first
-#'
-#' Internal use only. This exists so Windows, Linux, and Mac machines can have
+#' @details
+#' `.sortDotsUnderscoreFirst`: This exists so Windows, Linux, and Mac machines can have
 #' the same order after a sort. It will put dots and underscores first
 #' (with the sort key based on their second character, see examples.
 #' It also sorts lower case before upper case.
 #'
-#' @param obj  An arbitrary R object for which a \code{names} function
+#' @param obj  An arbitrary R object for which a `names` function
 #'              returns a character vector.
 #'
-#' @return The same object as \code{obj}, but sorted with .objects first.
+#' @return `.sortDotsUnderscoreFirst`: the same object as `obj`,
+#'   but sorted with dots and underscores first,
+#'   lower case before upper case.
 #'
 #' @author Eliot McIntire
 #' @export
-#' @rdname sortDotsUnderscoreFirst
+#' @rdname exportedMethods
 #'
 #' @examples
 #' items <- c(A = "a", Z = "z", `.D` = ".d", `_C` = "_C")
@@ -1056,7 +766,7 @@ copyFile <- Vectorize(copySingleFile, vectorize.args = c("from", "to"))
 }
 
 #' @export
-#' @rdname sortDotsUnderscoreFirst
+#' @rdname exportedMethods
 .orderDotsUnderscoreFirst <- function(obj) {
   if (!is.null(names(obj))) {
     namesObj <- names(obj)
@@ -1089,7 +799,7 @@ copyFile <- Vectorize(copySingleFile, vectorize.args = c("from", "to"))
 #' @param preDigest  A list of hashes.
 #' @param ...  Dots passed from Cache
 #'
-#' @return The same object as \code{obj}, but with 2 attributes set.
+#' @return The same object as `obj`, but with 2 attributes set.
 #'
 #' @author Eliot McIntire
 #' @importFrom data.table setattr
@@ -1159,27 +869,10 @@ nextNumericName <- function(string) {
   paste0(out, ".", theExt)
 }
 
-#' Grep system calls
-#'
-#' A faster way of grepping the system call stack than just
-#' \code{grep(sys.calls(), pattern = "test")}
-#'
-#' @param sysCalls The return from \code{sys.calls()}
-#' @param pattern Character, passed to grep
-#' @return
-#' Numeric vector, equivalent to return from \code{grep(sys.calls(), pattern = "test")},
-#' but faster if \code{sys.calls()} is very big.
-#'
-#' @export
-#' @keywords internal
-#' @rdname grepSysCalls
-.grepSysCalls <- function(sysCalls, pattern) {
-  scallsFirstElement <- lapply(sysCalls, function(x) x[1])
-  grep(scallsFirstElement, pattern = pattern)
-}
+
 
 #' @importFrom raster fromDisk
-dealWithClass <- function(obj, cachePath, drv, conn) {
+dealWithClass <- function(obj, cachePath, drv, conn, verbose = getOption("reproducible.verbose")) {
   # browser(expr = exists("._dealWithClass_1"))
   outputToSaveIsList <- is(obj, "list") # is.list is TRUE for anything, e.g., data.frame. We only want "list"
 
@@ -1232,12 +925,12 @@ dealWithClass <- function(obj, cachePath, drv, conn) {
 
   }
 
-
   if (any(inherits(obj, "SpatVector"), inherits(obj, "SpatRaster"))) {
-    if (!requireNamespace("terra") && getOption("reproducible.useTerra", FALSE))
+    if (!requireNamespace("terra", quietly = TRUE) && getOption("reproducible.useTerra", FALSE))
       stop("Please install terra package")
-
+    messageCache("...wrapping terra object for saving...", verboseLevel = 1, verbose = verbose)
     obj <- terra::wrap(obj)
+    messageCache("\b Done!", verboseLevel = 1, verbose = verbose)
   }
   obj
 }
@@ -1255,131 +948,6 @@ dealWithClass <- function(obj, cachePath, drv, conn) {
 
 
 
-
-
-
-#' A helper function to change the filename slot of \code{Raster*} objects
-#'
-#' This is intended for internal use, though it is exported because other packages
-#' use this. This function exists because when copying file-backed rasters, the
-#' usual mechanism of \code{writeRaster} can be very slow. This function allows
-#' for a user to optionally create a hard link to the old file, give it a new
-#' name, then update the filename slot(s) in the \code{Raster*} class object. This
-#' can be 100s of times faster for large rasters.
-#'
-#' @export
-#' @keywords internal
-#' @param obj An object. This function only has useful methods for \code{Raster*},
-#'   with all other classes being simply a pass-through
-#' @param curFilenames An optional character vector of filenames currently existing
-#'   and that are pointed to in the obj. If omitted, will take from the \code{obj}
-#'   using \code{Filenames(obj)}
-#' @param newFilenames An optional character vector of filenames to use instead of
-#'   the curFilenames. This can also be a single directory, in which case the
-#'   renaming will be given:
-#'   \code{file.path(newFilenames, basename(Filenames(obj, allowMultiple = FALSE)))}
-#' @rdname updateFilenameSlots
-updateFilenameSlots <- function(obj, curFilenames, newFilenames, isStack = NULL) {
-  UseMethod("updateFilenameSlots")
-}
-
-#' @rdname updateFilenameSlots
-#' @export
-#' @keywords internal
-updateFilenameSlots.default <- function(obj, ...)  {
-  obj
-}
-
-#' @rdname updateFilenameSlots
-#' @export
-#' @keywords internal
-updateFilenameSlots.list <- function(obj, ...)  {
-
-  areRasters <- vapply(obj, is, "RasterLayer", FUN.VALUE = logical(1))
-  if (all(areRasters)) {
-    # a separate option for list of RasterLayers because curFilename will be
-    #   as long as all the filenames because there is a method for lists;
-    #   passing this to updateFilaneSlots will fail if it is one RasterLayer
-    #   at a time
-    out <- updateFilenameSlots(raster::stack(obj), ...)
-    out <- raster::unstack(out)
-  } else {
-    out <- lapply(obj, function(o) {
-      updateFilenameSlots(o, ...)
-    })
-  }
-  out
-
-}
-
-#' @rdname updateFilenameSlots
-#' @export
-#' @keywords internal
-updateFilenameSlots.environment <- function(obj, ...)  {
-  if (is.null(names(obj))) {
-    names(obj) <- as.character(seq(obj))
-  }
-  lapply(obj, function(o) {
-    updateFilenameSlots(as.list(o), ...)
-  })
-}
-
-
-#' @rdname updateFilenameSlots
-#' @export
-#' @keywords internal
-updateFilenameSlots.Raster <- function(obj, curFilenames, newFilenames, isStack = NULL) {
-  if (isTRUE(getOption("reproducible.useNewDigestAlgorithm") < 2)) {
-    return(updateFilenameSlots2(obj, curFilenames, newFilenames, isStack))
-  }
-  if (missing(curFilenames)) {
-    curFilenames <- Filenames(obj, allowMultiple = FALSE)
-  }
-
-  if (missing(newFilenames)) stop("newFilenames can't be missing: either new filenames or a single directory")
-  # if newFilenames is a directory
-  areDirs <- dir.exists(newFilenames)
-  if (any(areDirs) && length(newFilenames) == 1) {
-    newFilenames <- file.path(newFilenames, basename(curFilenames))
-  }
-
-  if (length(curFilenames) > 1) {
-    for (i in seq_along(curFilenames)) {
-      if (is.list(obj)) {
-        slot(slot(obj[[i]], "file"), "name") <- newFilenames[i]
-      } else {
-        slot(slot(slot(obj, "layers")[[i]], "file"), "name") <- newFilenames[i]
-      }
-    }
-  } else {
-    if (is.null(isStack)) isStack <- is(obj, "RasterStack")
-    if (!isStack) {
-      slot(slot(obj, "file"), "name") <- newFilenames
-    } else {
-      # aiof <- allInOneFile(obj)
-
-      # if (isTRUE(aiof)) {
-      #   slot(obj, "filename") <- newFilenames
-      # } else {
-      if (length(newFilenames) == 1) {
-        newFilenames <- rep(newFilenames, nlayers(obj))
-      }
-      for (i in seq_len(nlayers(obj))) {
-        whFilename <- unique(match(withoutFinalNumeric(basename(newFilenames)),
-                                   withoutFinalNumeric(basename(curFilenames))))
-        isNAwhFn <- is.na(whFilename)
-        if (any(isNAwhFn))
-          whFilename <- i
-        slot(slot(obj@layers[[i]], "file"), "name") <- newFilenames[whFilename]
-      }
-      # }
-
-
-    }
-  }
-  obj
-}
-
 updateFilenameSlots2 <- function(obj, curFilenames, newFilenames, isStack = NULL) {
   whichNotGri <- grep("\\.gri$", curFilenames, invert = TRUE)
   curFilenamesNotGri <- curFilenames[whichNotGri]
@@ -1410,7 +978,7 @@ updateFilenameSlots2 <- function(obj, curFilenames, newFilenames, isStack = NULL
 #' Rasters are sometimes file-based, so the normal save and copy and assign
 #' mechanisms in R don't work for saving, copying and assigning.
 #' This function creates an explicit file copy of the file that is backing the raster,
-#' and changes the pointer (i.e., \code{filename(object)}) so that it is pointing
+#' and changes the pointer (i.e., `filename(object)`) so that it is pointing
 #' to the new file.
 #'
 #' @param obj The raster object to save to the repository.
@@ -1424,30 +992,14 @@ updateFilenameSlots2 <- function(obj, curFilenames, newFilenames, isStack = NULL
 #' @return A raster object and its newly located file backing.
 #'         Note that if this is a legitimate Cache repository, the new location
 #'         will be a subdirectory called \file{rasters/} of \file{repoDir/}.
-#'         If this is not a repository, the new location will be within \code{repoDir}.
+#'         If this is not a repository, the new location will be within `repoDir`.
 #'
 #' @author Eliot McIntire
-#' @export
 #' @importFrom digest digest
 #' @importFrom methods is selectMethod slot slot<-
 #' @importFrom raster dataType filename hasValues inMemory nlayers writeRaster
 #' @inheritParams Cache
 #' @rdname prepareFileBackedRaster
-#' @examples
-#' library(raster)
-#' # make a cache repository
-#' a <- Cache(rnorm, 1)
-#'
-#' r <- raster(extent(0,10,0,10), vals = 1:100)
-#'
-#' # write to disk manually -- will be in tempdir()
-#' r <- writeRaster(r, file = tempfile())
-#'
-#' # copy it to the cache repository
-#' r <- .prepareFileBackedRaster(r, tempdir())
-#'
-#' r # now in "rasters" subfolder of tempdir()
-#'
 .prepareFileBackedRaster <- function(obj, repoDir = NULL, overwrite = FALSE,
                                      drv = getOption("reproducible.drv", RSQLite::SQLite()),
                                      conn = getOption("reproducible.conn", NULL),
@@ -1560,3 +1112,5 @@ withoutFinalNumeric <- function(string) {
   woNumeric <- gsub("^(.+)\\_[[:digit:]]+$", "\\1", string1)
   paste0(woNumeric, ".", ext)
 }
+
+
