@@ -11,40 +11,9 @@ test_that("test miscellaneous fns (part 1)", {
   expect_true(all(unlist(lapply(searchFull(simplify = FALSE), is.environment))))
   expect_true(all(is.character(unlist(lapply(searchFull(simplify = FALSE), attributes)))))
 
-  # objectSize
-  a <- 1
-  b <- tempfile()
-  saveRDS(a, b)
-  expect_true(is.numeric(objSize(asPath(b))))
-  expect_true(is(objSize(asPath(b)), "lobstr_bytes"))
-
-  # objSizeSession
-  mess <- capture.output({d <- objSizeSession()})
-  expect_true(is.list(d))
-  g <- unlist(d)
-  expect_true(is.numeric(g))
-  expect_true(any(grepl("package", names(g))))
-
-  mess <- capture.output({d <- objSizeSession(1)})
-  expect_true(is.list(d))
-  g <- unlist(d)
-  expect_true(is.numeric(g))
-  expect_true(any(grepl("package", names(g))))
-  expect_true(all(names(g) %in% search() ))
-
-  mess <- capture.output({d1 <- objSizeSession(enclosingEnvs = FALSE)})
-  expect_true(is.list(d1))
-  g2 <- unlist(d1)
-  expect_true(is.numeric(g2))
-  expect_true(any(grepl("package", names(g2))))
-
   # NO LONGER RELIABLE TEST BECAUSE OF NEW REMOVAL OF PACKAGES fEB 24 2021
   # expect_true(sum(unlist(d1)) < sum(unlist(d)))
 
-  mess <- capture.output({d <- objSizeSession(0)})
-  expect_true(!is.list(d))
-  expect_true(is.numeric(d))
-
   # convertRasterPaths
   filenames <- normalizePath(c("/home/user1/Documents/file.txt", "/Users/user1/Documents/file.txt"),
                              winslash = "/", mustWork = FALSE)
@@ -81,6 +50,20 @@ test_that("test miscellaneous fns (part 1)", {
   a <- .formalsNotInCurrentDots(rnorm, n = 1, b = 2)
   b <- .formalsNotInCurrentDots(rnorm, dots = list(n = 1, b = 2))
   expect_identical(a,b)
+
+
+})
+
+test_that("objSize and objSizeSession", {
+  skip_on_cran()
+  # objectSize
+  a <- 1
+  b <- tempfile()
+  saveRDS(a, b)
+  expect_true(is.numeric(objSize(asPath(b))))
+  expect_true(is(objSize(asPath(b)), "lobstr_bytes"))
+
+
 })
 
 test_that("setting options works correctly", {
@@ -124,31 +107,31 @@ test_that("unrar is working as expected", {
   }, add = TRUE)
 
   rarPath <- file.path(tmpdir, "tmp.rar")
-  utils::zip(zipfile = rarPath, files = tmpfile)
-  unrar <- .whichExtractFn(archive = rarPath, args = "")
-  expect_true(identical(unrar$fun, "unrar"))
-  suppressWarnings(
-    expect_error(.callArchiveExtractFn(unrar$fun, files = "", args = list(exdir = tmpCache)))
-  )
+  out <- try(utils::zip(zipfile = rarPath, files = tmpfile)) # this should only be relevant if system can unrar
+  if (!is(out, "try-error")) {
+    unrar <- .whichExtractFn(archive = rarPath, args = "")
+    expect_true(identical(unrar$fun, "unrar"))
+    suppressWarnings(
+      expect_error(.callArchiveExtractFn(unrar$fun, files = "", args = list(exdir = tmpCache)))
+    )
+  }
 })
 
 test_that("test miscellaneous fns (part 2)", {
-  if (!requireNamespace("googledrive")) stop(requireNamespaceMsg("googledrive", "to use google drive files"))
+  skip_if_not_installed("googledrive")
   skip_if_no_token()
-  testInitOut <- testInit("raster", tmpFileExt = c(".tif", ".grd"))
+  testInitOut <- testInit("raster", tmpFileExt = c(".tif", ".grd"), needGoogle = TRUE)
   on.exit({
     testOnExit(testInitOut)
-    googledrive::drive_rm(googledrive::as_id(cloudFolderID))
-    googledrive::drive_rm(googledrive::as_id(tmpCloudFolderID))
+    try(googledrive::drive_rm(googledrive::as_id(cloudFolderID)))
+    try(googledrive::drive_rm(googledrive::as_id(tmpCloudFolderID)))
   }, add = TRUE)
 
   ras <- raster(extent(0,1,0,1), res  = 1, vals = 1)
   ras <- writeRaster(ras, file = tmpfile[1], overwrite = TRUE)
 
   gdriveLs1 <- data.frame(name = "GADM", id = "sdfsd", drive_resource = list(sdfsd = 1))
-  expect_warning({
-    tmpCloudFolderID <- checkAndMakeCloudFolderID(create = TRUE)
-  }, "No cloudFolderID supplied")
+  tmpCloudFolderID <- checkAndMakeCloudFolderID(create = TRUE)
   gdriveLs <- driveLs(cloudFolderID = NULL, "sdfsdf")
   expect_true(NROW(gdriveLs) == 0)
   expect_is(checkAndMakeCloudFolderID("testy"), "character")
@@ -160,11 +143,11 @@ test_that("test miscellaneous fns (part 2)", {
 
         mess1 <- capture_messages(expect_error(
           cloudUpload(isInRepo = data.frame(artifact = "sdfsdf"), outputHash = "sdfsiodfja",
-                      gdriveLs = gdriveLs1, cacheRepo = tmpCache)))
+                      gdriveLs = gdriveLs1, cachePath = tmpCache)))
       } else {
         mess1 <- capture_messages(expect_error(
           cloudUpload(isInRepo = data.frame(artifact = "sdfsdf"), outputHash = "sdfsiodfja",
-                      gdriveLs = gdriveLs1, cacheRepo = tmpCache)))
+                      gdriveLs = gdriveLs1, cachePath = tmpCache)))
       }
     })
   expect_true(grepl("Uploading local copy of", mess1))
@@ -182,7 +165,7 @@ test_that("test miscellaneous fns (part 2)", {
       # cloudFolderID can't be meaningless "character", but retry is TRUE
       warns <- capture_warnings({
         err <- capture_error({
-          cloudDownloadRasterBackend(output = ras, cacheRepo = tmpCache, cloudFolderID = "character")
+          cloudDownloadRasterBackend(output = ras, cachePath = tmpCache, cloudFolderID = "character")
         })
       })
       expect_true(is.null(err))
@@ -193,13 +176,12 @@ test_that("test miscellaneous fns (part 2)", {
     {
       mess1 <- capture_messages({
         err <- capture_error({
-          cloudUploadFromCache(isInCloud = FALSE, outputHash = "sdsdfs", saved = "life",
-                               cacheRepo = tmpCache)
+          cloudUploadFromCache(isInCloud = FALSE, outputHash = "sdsdfs", # saved = "life",
+                               cachePath = tmpCache)
         })
       })
       expect_true(all(grepl("cloudFolderID.*is missing, with no default", err)))
     })
-  expect_true(grepl("Uploading new cached object|with cacheId", mess1))
 
   a <- new.env(parent = emptyenv())
   a$a = list(ras, ras)
@@ -287,20 +269,21 @@ test_that("test miscellaneous fns", {
   whZero <- which(unlist(x1) == 0 )
   expect_true(all(unlist(lapply(whZero, function(ws) identical(x1[[ws]], a[[ws]])))))
 
-  if (FALSE) { ## TODO: fix empty messageDF outputs when run during non-interactive tests
-    out <- utils::capture.output(type = "message", messageDF(cbind(a = 1.1232), round = 2))
-    expect_true(is.character(out))
-    expect_identical(length(out), 2L) ## TODO: only passes when run line by line interactively
-    expect_true(is.numeric(as.numeric(gsub(".*: ", "", out)[2])))
+  out <- capture_messages(messageDF(cbind(a = 1.1232), round = 2))
+  expect_true(is.character(out))
+  expect_identical(length(out), 2L) ## TODO: only passes when run line by line interactively
+  expect_true(is.numeric(as.numeric(gsub("\033.*", "", gsub(".*: ", "", out)[2]))))
 
-    out <- utils::capture.output(type = "message", messageDF(cbind(a = 1.1232), round = 2, colnames = FALSE))
-    expect_true(is.character(out))
-    expect_identical(length(out), 1L) ## TODO: only passes when run line by line interactively
-    expect_true(is.numeric(as.numeric(gsub(".*: ", "", out)[2])))
+  out <- capture_messages(messageDF(cbind(a = 1.1232), round = 2, colnames = FALSE))
+  expect_true(is.character(out))
+  expect_identical(length(out), 1L) ## TODO: only passes when run line by line interactively
 
-    out <- utils::capture.output(type = "message", messageDF(1.1232, round = 2, colnames = TRUE))
-    expect_true(is.character(out))
-    expect_identical(length(out), 2L) ## TODO: only passes when run line by line interactively
-    expect_true(is.numeric(as.numeric(gsub(".*: ", "", out)[2])))
-  }
+  expect_true(is.numeric(as.numeric(gsub("\033.*", "", gsub(".*: ", "", out)))))
+
+
+  out <- capture_messages(messageDF(1.1232, round = 2, colnames = TRUE))
+  expect_true(is.character(out))
+  expect_identical(length(out), 2L) ## TODO: only passes when run line by line interactively
+  expect_true(is.numeric(as.numeric(gsub("\033.*", "", gsub(".*: ", "", out)[2]))))
 })
+
