@@ -5,7 +5,7 @@ test_that("preProcess fails if user provides non-existing file", {
     testOnExit(testInitOut)
   }, add = TRUE)
   testthat::with_mock(
-    `reproducible:::isInteractive` = function() {FALSE},
+    `isInteractive` = function() {FALSE},
     {
       co <- capture.output({
         co <- capture.output(type = "message", {
@@ -17,7 +17,7 @@ test_that("preProcess fails if user provides non-existing file", {
           })
         })
       })
-    }
+    }, .env = "reproducible"
   )
   expect_true(grepl("manual download", errMsg))
   expect_true(grepl("appendChecksumsTable", errMsg))
@@ -38,8 +38,8 @@ test_that("preProcess fails if user provides non-existing file", {
   options(optsOrig)
 
   testthat::with_mock(
-    `reproducible:::isInteractive` = function() {TRUE},
-    `reproducible:::.readline` = function(prompt) {"n"},
+    `isInteractive` = function() {TRUE},
+    `.readline` = function(prompt) {"n"},
     {
       co <- capture.output({
         co <- capture.output(type = "message", {
@@ -53,21 +53,20 @@ test_that("preProcess fails if user provides non-existing file", {
           })
         })
       })
-    }
+    }, .env = "reproducible"
   )
   expect_true(sum(grepl("Download failed", errMsg)) == 1)
-  # expect_true(sum(grepl("To prevent", errMsg)) == 1)
 
   optsOrig <- options('reproducible.interactiveOnDownloadFail' = TRUE)
   testthat::with_mock(
-    `reproducible:::isInteractive` = function() {TRUE},
-    `reproducible:::.readline` = function(prompt) {
+    `isInteractive` = function() {TRUE},
+    `.readline` = function(prompt) {
       theFile <- file.path(tmpdir, "rasterTestAA")
       write.table(theFile, file = theFile)
       zipFilename <- file.path(tmpdir, "rasterTest")
       zip(zipfile = zipFilename, files = theFile, flags = "-q")
       zipFilenameWithDotZip <- dir(tmpdir, pattern = "\\.zip", full.names = TRUE)
-      file.move(from = zipFilenameWithDotZip, to = zipFilename)
+      .file.move(from = zipFilenameWithDotZip, to = zipFilename)
       "y"
       },
     {
@@ -83,7 +82,7 @@ test_that("preProcess fails if user provides non-existing file", {
           })
       })
     })
-  })
+  }, .env = "reproducible")
   expect_true(sum(grepl("manual download", mess)) == 1)
   expect_true(sum(grepl("To prevent", mess)) == 1)
   if (isWindows()) # windows can't tell a zip file is a zip file, but Unix-alikes can
