@@ -5,7 +5,7 @@ test_that("test reproducible.verbose", {
     testOnExit(testInitOut)
   }, add = TRUE)
 
-  warn <- capture_warnings(Cache(rnorm, 1, cacheRepo = tmpdir))
+  warn <- capture_warnings(Cache(rnorm, 1, cachePath = tmpdir))
   expect_is(.reproEnv$cacheTimings, "data.frame") ##
   expect_true(NROW(.reproEnv$cacheTimings) == 4)  ##
   expect_true(NCOL(.reproEnv$cacheTimings) == 4)  ##
@@ -14,9 +14,10 @@ test_that("test reproducible.verbose", {
   a <- sample(1e4)
 
   saveRDS(a, file = tmpfile)
-  out1 <- Cache(readRDS, tmpfile, cacheRepo = tmpdir)
+  out1 <- Cache(readRDS, tmpfile, cachePath = tmpdir)
   out1Details <- .reproEnv$hashDetailsAll
-  out2 <- Cache(readRDS, asPath(tmpfile), cacheRepo = tmpdir)
+  ap <- asPath(tmpfile)
+  out2 <- Cache(readRDS, ap, cachePath = tmpdir)
   out2Details <- .reproEnv$hashDetailsAll
 
   # should be vastly larger when actual file, rather than just filename
